#!/usr/bin/env node

'use strict'

const _ = require('ninjs-lodash')
const sass = require('../lib/sass')

const DEMO = _.path.join(_.$('paths.root'), 'demo')

const APP_SRC = _.path.join(DEMO, "app", "css", "styles.scss")
const APP_DEST = _.path.join(DEMO, "app", "public", "css", "styles.css")
const APP_INC = []

const CDN_SRC = _.path.join(_.$("paths.code"), "sites", "snapptop.com", "apps", "cdn.snapptop.com", "css", "styles.scss")
const CDN_DEST = _.path.join(_.$("paths.dev"), "sites", "snapptop.com", "cdn.snapptop.com", "public", "css", "styles.css")

const HEADINGS_SRC = _.path.join(DEMO, "headings", "css", "styles.scss")
const HEADINGS_DEST = _.path.join(DEMO, "headings", "public", "css", "styles.css")
const HEADINGS_INC = []

exports = module.exports = {
  "help": {
    "options": { },
    "handler": (options) => {
      _.log(`\nTODO: print Help Info for all Commands\n`)
    },
    "text": "Gets help info for all commands"
  },
  "settings": {
    "options": { "key": "" },
    "handler": (options) => {
      let key = _.get(options, "key") || ""
      let val = _.$(key)
      if(val) _.jslog(val)
    },
    "text": `Gets global settings (_.$())\n\nOR\n\nGets a specific global setting designated by --key=<key> (_.$(key))`
  },
  "app": {
    "render": {
      "options": { enabled: true, file: "", dest: "", data: "", includePaths: [] },
      "handler": (options) => { sass.renderApp(options, _.logcb) },
      "text": "Builds/Optimizes/AutoPrefixes/Minifies file entry -> dest/styles.css"
    },
    "demo": {
      "options": {
        "enabled": true,
        "file": APP_SRC,
        "dest": APP_DEST,
        "data": "",
        "includePaths": APP_INC
      },
      "handler": (options) => { sass.renderApp(options, _.logcb) },
      "text": "Builds demo app and prints result -> see ./demo/app/public/css/** for output"
    },
    "cdn": {
      "options": {
        "enabled": true,
        "file": CDN_SRC,
        "dest": CDN_DEST,
        "data": "",
        "includePaths": []
      },
      "handler": (options) => { sass.renderApp(options, _.logcb) },
      "text": ""
    }
  },
  "headings": {
    "render": {
      "options": { "enabled": true, "file": "", "dest": "", "data": "", "includePaths": [] },
      "handler": (options) => { sass.renderHeadings(options, _.logcb) },
      "text": "Returns dynamic css for headings"
    },
    "demo": {
      "options": {
        "enabled": true,
        "file": HEADINGS_SRC,
        "dest": HEADINGS_DEST,
        "data": "",
        "includePaths": HEADINGS_INC
      },
      "handler": (options) => { sass.renderHeadings(options, _.logcb) },
      "text": "Builds demo headings using LibSass and prints result -> see ./demo/headings/public/css/** for output"
    }
  }
}

_.cli(exports)